#[non_exhaustive]pub enum EventRoleType {
Principal,
Participant,
Official,
Witness,
Custom(Uri),
}Expand description
Standard event roles.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Principal
The person is the principal person of the event.
For example, the principal of a birth event is the person that was born.
Participant
A participant in the event.
Official
A person officiating the event.
Witness
A witness of the event.
Custom(Uri)