#[non_exhaustive]pub enum IdentifierType {
Primary,
Authority,
Deprecated,
Custom(Uri),
}Expand description
Standard identifier types. Custom identifier types should not have a value of “$” since this is reserved for identifiers without a type in JSON.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Primary
The primary identifier for the resource.
The value of the identifier MUST resolve to the instance of Subject to which the identifier applies.
Authority
An identifier for the resource in an external authority or other expert system.
The value of the identifier MUST resolve to a public, authoritative, source for information about the Subject to which the identifier applies.
Deprecated
An identifier that has been relegated, deprecated, or otherwise downgraded.
This identifier is commonly used as the result of a merge when what was once a primary identifier for a resource is no longer the primary identifier. The value of the identifier MUST resolve to the instance of Subject to which the identifier applies.
Custom(Uri)